@@ -707,27 +707,3 @@ print.sj_wcor <- function(x, ...) {
 print.sj_anova_stat <- function(x, digits = 3, ...) {
   print.data.frame(sjmisc::round_num(x, digits), ..., row.names = TRUE)
 }
-
-
-#' @export
-getME.brmsfit <- function(object, name, ...) {
-  rv <- NULL
-  if (name == "X") {
-    rv <- as.matrix(cbind(1, insight::get_data(object)[insight::find_predictors(object, effects = "fixed")]))
-    colnames(rv)[1] = "Intercept"
-  }
-  rv
-}
-
-
-#' @export
-getME.stanreg <- function(object, name, ...) {
-  if (!requireNamespace("rstanarm", quietly = TRUE))
-    stop("Package `rstanarm` needed for this function to work. Please install it.", call. = FALSE)
-
-  rv <- NULL
-  if (name == "X") {
-    rv <- rstanarm::get_x(object)
-  }
-  rv
-}
